proc datasets lib = work kill; run;
option linesize = 200 pagesize = 5000 mprint;
dm 'log; clear; output; clear;';

%let execpath = " ";
%let Path = " ";
%macro setexecpath;
  %let execpath = %sysfunc(getoption(sysin));
  %if %length(&execpath) = 0 %then
    %let execpath = %sysget(sas_execfilepath);
  data _null_;
    do i = length("&execpath") to 1 by -1;
      if substr("&execpath", i, 1) = "\" then do;
        call symput("Path", substr("&execpath", 1, i));
        stop;
      end;
    end;
  run;
%mend setexecpath;
%setexecpath;
libname Out "&Path";
%include "&Path.kmatrisk_v200.sas";

proc format;
value risk 1='ALL' 2='low-risk AML' 3='high-risk AML';
data BMT;
length GroupC $10.;
input Group T Status @@;
if Group = 1 then GroupC = 'ALL';
if Group = 2 then GroupC = 'low-risk';
if Group = 3 then GroupC = 'high-risk';
*format Group risk.;
label T='Time to Relapse';
datalines;
1 2081 0 1 1602 0 1 1496 0 1 1462 0 1 1433 0
1 1377 0 1 1330 0 1  996 0 1  226 0 1 1199 0
1 1111 0 1  530 0 1 1182 0 1 1167 0 1  418 1
1  383 1 1  276 1 1  104 1 1  609 1 1  172 1
1  487 1 1  662 1 1  194 1 1  230 1 1  526 1
1  122 1 1  129 1 1   74 1 1  122 1 1   86 1
1  466 1 1  192 1 1  109 1 1   55 1 1    1 1
1  107 1 1  110 1 1  332 1 2 2569 0 2 2506 0  
2 2409 0 2 2218 0 2 1857 0 2 1829 0 2 1562 0  
2 1470 0 2 1363 0 2 1030 0 2  860 0 2 1258 0  
2 2246 0 2 1870 0 2 1799 0 2 1709 0 2 1674 0  
2 1568 0 2 1527 0 2 1324 0 2  957 0 2  932 0  
2  847 0 2  848 0 2 1850 0 2 1843 0 2 1535 0  
2 1447 0 2 1384 0 2  414 1 2 2204 1 2 1063 1  
2  481 1 2  105 1 2  641 1 2  390 1 2  288 1  
2  421 1 2   79 1 2  748 1 2  486 1 2   48 1  
2  272 1 2 1074 1 2  381 1 2   10 1 2   53 1  
2   80 1 2   35 1 2  248 1 2  704 1 2  211 1  
2  219 1 2  606 1 3 2640 0 3 2430 0 3 2252 0  
3 2140 0 3 2133 0 3 1238 0 3 1631 0 3 2024 0  
3 1345 0 3 1136 0 3  845 0 3  422 1 3  162 1  
3   84 1 3  100 1 3    2 1 3   47 1 3  242 1  
3  456 1 3  268 1 3  318 1 3   32 1 3  467 1  
3   47 1 3  390 1 3  183 1 3  105 1 3  115 1  
3  164 1 3   93 1 3  120 1 3   80 1 3  677 1  
3   64 1 3  168 1 3   74 1 3   16 1 3  157 1  
3  625 1 3   48 1 3  273 1 3   63 1 3   76 1  
3  113 1 3  363 1  
;

/*****************************************************************/
/* Sample color pattern */
%let color1 = 'cx5ECD22';
%let color2 = 'cxFAA55C';
%let color3 = 'cxE04251';
%let color4 = 'cx75B5E1';

/*****************************************************************/
/* Graph print setting */
/* aspect ratio "19:12" (for presentation) */
goptions reset = all;
goptions vsize = 12 in hsize = 19 in htitle = 3 htext = 3;
options linesize = 98 pagesize = 200;


/* Censor: needle, Atrisk: display */
filename grafout "&Path.Sample1.bmp";
goptions device = bmp gsfname = grafout gsfmode = replace;
goptions ftext = "Times New Roman";
%km_data(
  BMT, T, GroupC, Status, 0,
  out = graph, anno = anno,
  afont = "'Times New Roman'",
  censEXT = 1, cHeight = 0.025, cWidth = 5,
  atrisk = 1, atriskorder = 0 to 3000 by 500,
  Base = 0, Step = 4, Size = 3, Label = "No. at risk"
);

proc gplot data = Graph;
  plot (Sv1 Sv2 Sv3) * T /
      anno = anno autovref cautovref = cxE9DECA
      overlay skipmiss noframe nolegend
      haxis = axis1 vaxis = axis2;
  axis1 label = ('Time') major=(w=2 height=0.7) w=2 minor = none
    order = (0 to 3000 by 500) offset = (2, 7);
  axis2 label = (a=90 'Proportion of Survival') major=(w=2 height=1) w=2 minor = none
    offset = (2, 2) order = (0 to 1 by 0.2);
  symbol1 i = steplj c="&color1." w = 5;
  symbol2 i = steplj c="&color2." w = 5;
  symbol3 i = steplj c="&color3." w = 5;
run; quit;



/* Censor: dot-square-x, Atrisk: display */
filename grafout "&Path.Sample2.bmp";
goptions device = bmp gsfname = grafout gsfmode = replace;
goptions ftext = "Times New Roman";
%km_data(
  BMT, T, GroupC, Status, 0,
  out = graph, anno = anno,
  afont = "'Times New Roman'",
  censEXT = 0, cHeight = 0.025, cWidth = 5,
  atrisk = 1, atriskorder = 0 to 3000 by 500,
  Base = 0, Step = 4, Size = 3, Label = "No. at risk"
);

proc gplot data = Graph;
  plot (Sv1 Sv2 Sv3 CSDF1 CSDF2 CSDF3) * T /
      anno = anno autovref cautovref = cxE9DECA
      overlay skipmiss noframe nolegend
      haxis = axis1 vaxis = axis2;
  axis1 label = ('Time') major=(w=2 height=0.7) w=2 minor = none
    order = (0 to 3000 by 500) offset = (2, 7);
  axis2 label = (a=90 'Proportion of Survival') major=(w=2 height=1) w=2 minor = none
    offset = (2, 2) order = (0 to 1 by 0.2);
  symbol1 i = steplj c="&color1." w = 5;
  symbol2 i = steplj c="&color2." w = 5;
  symbol3 i = steplj c="&color3." w = 5;
  symbol4 i = none c="&color1." h = 2 v = dot;
  symbol5 i = none c="&color2." h = 2 v = square;
  symbol6 i = none c="&color3." h = 2 v = x;
run; quit;



/* Censor: needle, Atrisk: nondisplay */
filename grafout "&Path.Sample3.bmp";
goptions device = bmp gsfname = grafout gsfmode = replace;
goptions ftext = "Calibri";
%km_data(
  BMT, T, GroupC, Status, 0,
  out = graph, anno = anno,
  afont = "'Calibri'",
  censEXT = 1, cHeight = 0.02, cWidth = 5,
  atrisk = 0, atriskorder = 0 to 3000 by 500,
  Base = 0, Step = 4, Size = 3, Label = "No. at risk"
);

proc gplot data = Graph;
  plot (Sv1 Sv2 Sv3) * T /
      anno = anno autovref cautovref = cxE9DECA
      overlay skipmiss noframe nolegend
      haxis = axis1 vaxis = axis2;
  axis1 label = ('Time') major=(w=2 height=0.7) w=2 minor = none
    order = (0 to 3000 by 500) offset = (2, 7);
  axis2 label = (a=90 'Proportion of Survival') major=(w=2 height=1) w=2 minor = none
    offset = (2, 2) order = (0 to 1 by 0.2);
  symbol1 i = steplj c="&color1." w = 5;
  symbol2 i = steplj c="&color2." w = 5;
  symbol3 i = steplj c="&color3." w = 5;
run; quit;




/*****************************************************************/
/* Graph print setting */
/* aspect ratio "12:12" (for presentation) */
goptions reset = all;
goptions vsize = 12 in hsize = 12 in htitle = 2 htext = 2;
options linesize = 98 pagesize = 200;

/* Censor: dot-square-x, Atrisk: display */
filename grafout "&Path.Sample4.bmp";
goptions device = bmp gsfname = grafout gsfmode = replace;
goptions ftext = "Times New Roman";
%km_data(
  BMT, T, GroupC, Status, 0,
  out = graph, anno = anno,
  afont = "'Times New Roman'",
  censEXT = 0, cHeight = 0.025, cWidth = 5,
  atrisk = 1, atriskorder = 0 to 3000 by 500,
  Base = 0, Step = 3, Size = 2, Label = "No. at risk"
);

proc gplot data = Graph;
  plot (Sv1 Sv2 Sv3 CSDF1 CSDF2 CSDF3) * T /
      anno = anno autovref cautovref = cxE9DECA
      overlay skipmiss noframe nolegend
      haxis = axis1 vaxis = axis2;
  axis1 label = ('Time') major=(w=2 height=0.7) w=2 minor = none
    order = (0 to 3000 by 500) offset = (2, 7);
  axis2 label = (a=90 'Proportion of Survival') major=(w=2 height=1) w=2 minor = none
    offset = (0, 2) order = (0 to 1 by 0.2);
  symbol1 i = steplj c="&color1." w = 5;
  symbol2 i = steplj c="&color2." w = 5;
  symbol3 i = steplj c="&color3." w = 5;
  symbol4 i = none c="&color1." h = 2 v = dot;
  symbol5 i = none c="&color2." h = 2 v = square;
  symbol6 i = none c="&color3." h = 2 v = x;
run; quit;



/* Censor: needle, Atrisk: display, one stratum (error) */
filename grafout "&Path.Sample5.bmp";
goptions device = bmp gsfname = grafout gsfmode = replace;
goptions ftext = "Times New Roman";
%km_data(
  BMT(where=(GroupC="ALL")), T, GroupC, Status, 0,
  out = graph, anno = anno,
  afont = "'Times New Roman'",
  censEXT = 1, cHeight = 0.025, cWidth = 5,
  atrisk = 1, atriskorder = 0 to 3000 by 500,
  Base = 0, Step = 4, Size = 3, Label = "No. at risk"
);

proc gplot data = Graph;
  plot (SURVIVAL) * T /
      anno = anno autovref cautovref = cxE9DECA
      overlay skipmiss noframe nolegend
      haxis = axis1 vaxis = axis2;
  axis1 label = ('Time') major=(w=2 height=0.7) w=2 minor = none
    order = (0 to 3000 by 500) offset = (2, 7);
  axis2 label = (a=90 'Proportion of Survival') major=(w=2 height=1) w=2 minor = none
    offset = (2, 2) order = (0 to 1 by 0.2);
  symbol1 i = steplj c="cx5ECD22" w = 5;
run; quit;
